@@ -24,8 +24,7 @@ from eigeningenuity.events import get_eventlog
 from eigeningenuity.assetmodel import get_assetmodel
 from eigeningenuity.smartdash import get_smartdash
 from eigeningenuity.sql import get_sql
+from eigeningenuity.settings import set_azure_client_id, set_azure_tenant_id, disable_azure_auth, disable_token_cache, clear_token_cache
 
-from eigeningenuity.core import *
-
-__all__ = ["get_historian", "get_assetmodel", "get_elastic", "get_sql", "get_eventlog", "get_smartdash", "list_historians", "get_default_historian_name", "EigenServer"]
+__all__ = ["get_historian", "get_assetmodel", "get_elastic", "get_sql", "get_eventlog", "get_smartdash", "list_historians", "get_default_historian_name", "EigenServer", "set_azure_client_id", "set_azure_tenant_id", "disable_azure_auth", "disable_token_cache", "clear_token_cache"]
 __version__ = pkg_resources.require("python-eigen-ingenuity")[0].version
