@@ -45,7 +45,7 @@ class AssetModel (object):
     def _testConnection(self):
         """Preflight Request to verify connection to ingenuity"""
         try:
-            status = requests.get(self.baseurl).status_code
+            status = requests.get(self.baseurl, verify=False).status_code
         except (URLError, ConnectionError):
             raise ConnectionError("Failed to connect to ingenuity instance at " + self.baseurl + ". Please check the url is correct and the instance is up.")
 
@@ -94,7 +94,7 @@ class AssetModel (object):
 
         Args:
             node:
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             A Json containing all nodes with a relation to any node that meets the criteria, and their relationship type.
@@ -108,17 +108,29 @@ class AssetModel (object):
         response = self._doJsonCommonMenuRequest("relatedAssets", args)
         relatedassets = response["relatedAssets"]["graphapi"]
 
+        newAssets=[]
+
+        for item in relatedassets:
+            relations = item["relations"]
+            for relation in relations:
+                newItem = {"asset": item["asset"]}
+                newItem["relationName"] = relation["relationName"]
+                newItem["direction"] = relation["direction"]
+                newAssets.append(newItem)
+
+
+
         if output == "raw":
             return response
         if output == "json":
-            return relatedassets
+            return newAssets
         if output == "df":
-            return pd.json_normalize(relatedassets).drop(columns=["asset.externalId"])
+            return pd.json_normalize(newAssets).drop(columns=["asset.externalId"])
         if output == "file":
             if filepath is None:
                 filepath = node + "-RelatedAssets-" + str(dt.datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
             with open(filepath + ".json", "w") as f:
-                f.write(json.dumps(relatedassets, indent=4))
+                f.write(json.dumps(newAssets, indent=4))
 
     def getRelatedMeasurementsCypher(self, query:str, prop:str="code", measurement:str="", output="json"):
         """
@@ -126,8 +138,8 @@ class AssetModel (object):
 
         Args: 
             nodes: The value of the property to match
-            prop: (Optional) The property on to query nodes on. Defaults to code.
-            measurement: (Optional) Return only tags for a specified measurement type. Defaults to return all tags.
+            prop (Optional): The property on to query nodes on. Defaults to code.
+            measurement (Optional): Return only tags for a specified measurement type. Defaults to return all tags.
 
         Returns:
             A Json containing all nodes with a relation to any node that meets the criteria, and their relationship type.
@@ -170,7 +182,7 @@ class AssetModel (object):
 
         Args: 
             node: The code (ID) of the node to get related measurements from
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             A Json containing all nodes with a relation to any node that meets the criteria, and their relationship type.
@@ -198,9 +210,9 @@ class AssetModel (object):
 
         Args:
             node: The name of the node to query documents for
-            match: (Optional) Filter returned Documents to those with filenames matching a string
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API; "json" - A processed version of the json response; "df" - A formatted pandas dataframe object; "download" - Downloads the files to a local directory"
-            directory: (Optional) Name and path to the directory created/used for downloaded documents. If omitted, will download files to current directory. Has no effect unless output is "download".
+            match (Optional): Filter returned Documents to those with filenames matching a string
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API; "json" - A processed version of the json response; "df" - A formatted pandas dataframe object; "download" - Downloads the files to a local directory"
+            directory (Optional): Name and path to the directory created/used for downloaded documents. If omitted, will download files to current directory. Has no effect unless output is "download".
 
         Returns:
             The set of all documents related to the nodes, the format is dependent on the output parameter. If output is "download", it returns instead the files themselves
@@ -251,21 +263,27 @@ class AssetModel (object):
                         f.close()
 
 
-    def getLabels(self):
+    def getLabels(self,code:str=None):
         """
-        List all labels used in an assetmodel instance
+        List all labels used in an assetmodel instance, or the list of all labels of a given node
 
         Args:
-            N/A
+           code (Optional): The value of the code property for the node to get labels for
         Returns:
-            A list of all node labels/types present in the model
+            A list of all node labels/types present in the model, or, if specified, for a node
         """
-        args = {"q": "call db.labels()"}
+        if code is None:
+            args = {"q": "call db.labels()"}
+        else: 
+            args = {"q": "match (n:EI_CURRENT {code: '" + code + "'}) return labels(n)"}
         response = self._doJsonCypherRequest("EXECUTE",args)
 
         labels = []
-        for label in response:
-            labels.append(label["label"])
+        if code is None:
+            for label in response:
+                labels.append(label["label"])
+        else:
+            labels = response[0]['labels(n)']
 
         return labels
 
@@ -277,8 +295,8 @@ class AssetModel (object):
             node: The name of the node to query documents for
             start: Timestamp of beginning of time window to search for events, also accepts strings like "30 mins ago"
             end: Timestamp of end of time window to search for events
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API; "json" - A processed version of the json response; "df" - A formatted pandas dataframe object; "download" - Downloads the files to a local directory"
-            directory: (Optional) Name and path to the directory created/used for downloaded documents. If omitted, will download files to current directory. Has no effect unless output is "download".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API; "json" - A processed version of the json response; "df" - A formatted pandas dataframe object; "download" - Downloads the files to a local directory"
+            directory (Optional): Name and path to the directory created/used for downloaded documents. If omitted, will download files to current directory. Has no effect unless output is "download".
 
         Returns:
             The set of all documents related to the nodes, the format is dependent on the output parameter. If output is "download", it returns instead the files themselves
@@ -348,7 +366,7 @@ class AssetModel (object):
         Args:
             prop: The property on which to match
             match: A list of nodes to return properties for
-            exact: (Optional) Whether to only return nodes where the prop is equal to match, or nodes where prop contains match. Defaults to False
+            exact (Optional): Whether to only return nodes where the prop is equal to match, or nodes where prop contains match. Defaults to False
     
         Returns:
             A Json containing all nodes that contains the criteria.
