@@ -52,18 +52,18 @@ class JsonBridgeHistorian (object):
 
     def _testConnection(self):
         try:
-            status = requests.get(self.serverurl).status_code
+            status = requests.get(self.serverurl, verify=False).status_code
             if status != 200:
                 raise ConnectionError(
                     "Invalid API Response from " + self.serverurl + ". Please check the url is correct and the instance is up.")
         except (URLError, ConnectionError):
-            raise ConnectionError ("Failed to connect to ingenuity instance at " + self.baseurl + ". Please check the url is correct and the instance is up.")
+            raise ConnectionError ("Failed to connect to ingenuity instance at " + self.serverurl + ". Please check the url is correct and the instance is up.")
 
     def listDataTags(self, wildcard):
         """Return a list of all tags that match a given wildcard, or all tags in the historian
 
         Args:
-            wildcard: (Optional) Return all tags that contain this value in their name. Defaults to All Tags in historian.
+            wildcard (Optional): Return all tags that contain this value in their name. Defaults to All Tags in historian.
 
         Returns:
             A list of all tags containing wildcard
@@ -87,7 +87,7 @@ class JsonBridgeHistorian (object):
 
         Args:
             tags: A datatag, or list of datatags
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             Units, unit multiplier, and description for each datatag, the format is dependent on the output parameter
@@ -131,7 +131,7 @@ class JsonBridgeHistorian (object):
 
         Args:
             tags: A datatag, or list of datatags
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             A timestamps, values and statuses for each tag, the format is dependent on the output parameter
@@ -159,9 +159,9 @@ class JsonBridgeHistorian (object):
             return response
         elif output == "json":
             if len(force_list(tags)) == 1:
-                return response[tags]
+                return items[tags]
             else:
-                return response
+                return items
         elif output == "string":
             return json.dumps(items)
         elif output == "df":
@@ -179,7 +179,7 @@ class JsonBridgeHistorian (object):
         Args:
             tags: A datatag, or list of datatags
             timestamps: One or more timestamps for which to return a datapoint. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             Timestamps, values and statuses for each datapoint returned, the format is dependent on the output parameter
@@ -228,8 +228,8 @@ class JsonBridgeHistorian (object):
             tags: A datatag, or list of datatags
             start: Start of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
             end: End of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
-            maxpoints: (Optional) The maximum number of points to return. Defaults to 1000
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            maxpoints (Optional): The maximum number of points to return. Defaults to 1000
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             Timestamps, values and statuses for each datapoint returned, the format is dependent on the output parameter
@@ -281,8 +281,8 @@ class JsonBridgeHistorian (object):
             tags: A datatag, or list of datatags
             start: Start of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
             end: End of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
-            count: (Optional) Number of points to return, evenly spaced across the given time range. Defaults to 1000
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            count (Optional): Number of points to return, evenly spaced across the given time range. Defaults to 1000
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             Timestamps, values and statuses for each datapoint returned, the format is dependent on the output parameter
@@ -334,9 +334,9 @@ class JsonBridgeHistorian (object):
             tags: A datatag, or list of datatags
             start: Start of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
             end: End of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
-            fields: (Optional) The aggregates to be calculated, accepts any subset of ["min","max","mean","stddev","var","numgood","numbad"]. Defaults to all aggregates.
-            count: (Optional) Number of intervals to split the time window into, returning aggregates over each interval. Defaults to 1
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            fields (Optional): The aggregates to be calculated, accepts any subset of ["min","max","mean","stddev","var","numgood","numbad"]. Defaults to all aggregates.
+            count (Optional): Number of intervals to split the time window into, returning aggregates over each interval. Defaults to 1
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             Timestamps, values and statuses for each datapoint returned, the format is dependent on the output parameter
@@ -377,7 +377,7 @@ class JsonBridgeHistorian (object):
         elif output == "string":
             return json.dumps(response)
         elif output == "df":
-            return aggToDf(response)
+            return aggToDf(response,fields)
         elif output == "csv":
             order = ["tag","start","end","min","max","avg","var","stddev","count","numgood","numbad"]
             return csvWriter(response,self.historian,filepath,multi_csv,"GetAggregates",order,True)
@@ -394,9 +394,9 @@ class JsonBridgeHistorian (object):
             tags: A datatag, or list of datatags
             start: Start of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
             end: End of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
-            window: (Optional) Sub-interval of time to divide the timeframe into as a multiple of seconds,minutes,hours,days or years. (e.g. "1d" for 1 day or "2h" for 2 hours etc). Defaults to the entire timeframe.
-            fields: (Optional) The aggregates to be calculated, accepts any subset of ["min","max","mean","stddev","var","numgood","numbad"]. Defaults to all aggregates.
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            window (Optional): Sub-interval of time to divide the timeframe into as a multiple of seconds,minutes,hours,days or years. (e.g. "1d" for 1 day or "2h" for 2 hours etc). Defaults to the entire timeframe.
+            fields (Optional): The aggregates to be calculated, accepts any subset of ["min","max","mean","stddev","var","numgood","numbad"]. Defaults to all aggregates.
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             Timestamps, values and statuses for each datapoint returned, the format is dependent on the output parameter
@@ -452,7 +452,7 @@ class JsonBridgeHistorian (object):
         elif output == "string":
             return json.dumps(response)
         elif output == "df":
-            return aggToDf(response)
+            return aggToDf(response,fields)
         elif output == "csv":
             order = ["tag","start","end","min","max","avg","var","stddev","count","numgood","numbad"]
             return csvWriter(response,self.historian,filepath,multi_csv,"GetAggregateIntervals",order,True)
@@ -466,7 +466,7 @@ class JsonBridgeHistorian (object):
             tags: A datatag, or list of datatags
             start: Start of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
             end: End of the time range. Accepts epoch milliseconds, python datetime objects, or strings of format dd-mm-YYYYTHH:MM:DD
-            output: (Optional) The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
+            output (Optional): The format in which to return the data. Accepts one of: "raw" - The raw json returned by the API, "json" - A processed version of the json response, "df" - A formatted pandas dataframe object. Defaults to "json".
 
         Returns:
             The number of raw datapoints in the interval, per tag.
@@ -588,7 +588,7 @@ class JsonBridgeHistorian (object):
             Success: A boolean representing the successful push of data. True means all csvs were successfully imported, False means at least one csv failed.
         """
         success = []
-        for filepath in filepaths:
+        for filepath in force_list(filepaths):
             with open(filepath, "r") as file:
                 csv_reader = csv.reader(file, delimiter=',')
                 data = list(csv_reader)
@@ -656,14 +656,14 @@ class DataPoint(object): # LEGACY OBJECT
 
         if status is None:
             self.status = "OK"
-        elif status == "OK" or self.status == "BAD":
+        elif status == "OK" or status == "BAD":
             self.status = status
         else:
             raise EigenException("Unrecognised Status")
 
         # Convert timestamp from python datetime or tuple into python floating point epoch seconds
-        self.datetime = datetime.fromtimestamp(timestamp)
-        self.timestamp = pythonTimeToFloatingSecs(timestamp)
+        self.datetime = datetime.fromtimestamp(time_to_epoch_millis(timestamp)/1000)
+        self.timestamp = pythonTimeToFloatingSecs(time_to_epoch_millis(timestamp)/1000)
 
 
     def __str__(self):
@@ -732,8 +732,8 @@ def get_historian(instance: str = None, eigenserver: EigenServer = None) -> Json
     """Instantiate a historian object for the given instance.
 
     Args:
-        instance: (Optional) The name of the historian to connect to. Defaults to the default historian of the EigenServer.
-        eigenserver: (Optional) An EigenServer Object linked to the ingenuity url containing the historian. Can be omitted if environmental variable "EIGENSERVER" exists and is equal to the Ingenuity base url
+        instance (Optional): The name of the historian to connect to. Defaults to the default historian of the EigenServer.
+        eigenserver (Optional): An EigenServer Object linked to the ingenuity url containing the historian. Can be omitted if environmental variable "EIGENSERVER" exists and is equal to the Ingenuity base url
 
     Returns:
         An Object that can be used to query historian data.
@@ -756,7 +756,7 @@ def list_historians(eigenserver=None) -> list:
     """List all historian instances in EigenServer.
 
     Args:
-        eigenserver: (Optional) An EigenServer Object linked to the ingenuity url containing the historian. Can be omitted if environmental variable "EIGENSERVER" exists and is equal to the Ingenuity base url
+        eigenserver (Optional): An EigenServer Object linked to the ingenuity url containing the historian. Can be omitted if environmental variable "EIGENSERVER" exists and is equal to the Ingenuity base url
 
     Returns:
         A list of all historians on the server
@@ -771,7 +771,7 @@ def get_default_historian_name(eigenserver=None) -> str:
     """Get the default historian of an EigenServer.
 
     Args:
-        eigenserver: (Optional) An EigenServer Object linked to the ingenuity url containing the historian. Can be omitted if environmental variable "EIGENSERVER" exists and is equal to the Ingenuity base url
+        eigenserver (Optional): An EigenServer Object linked to the ingenuity url containing the historian. Can be omitted if environmental variable "EIGENSERVER" exists and is equal to the Ingenuity base url
 
     Returns:
         The name of the default historian
