@@ -87,7 +87,7 @@ def get_smartdash(eigenserver = None):
 
     url = eigenserver.getEigenServerUrl() + "smartdash-servlet"
 
-    x = requests.get(url).status_code
+    x = requests.get(url, verify=False).status_code
 
     if x != 200:
         url = eigenserver.getAppUrl("dashboards-applet")
